package com.jln.system.web.action.mqtt.server.impl;

import com.alibaba.fastjson.JSONObject;
import com.jln.common.enums.MqttEnum;
import com.jln.system.web.action.mqtt.MqttStartClient;
import com.jln.system.web.action.mqtt.XBMqttDataUtil;
import com.jln.system.web.action.mqtt.mapper.ScadaBiMapper;
import com.jln.system.web.action.mqtt.pojo.dto.JsonDataDto;
import com.jln.system.web.action.mqtt.pojo.vo.BldzCclmVo;
import com.jln.system.web.action.mqtt.server.SendMqttServer;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.*;

@Service
@Slf4j
public class SendMqttServerImpl implements SendMqttServer {
    @Autowired
    private MqttStartClient mqttStartClient;
    @Autowired
    private ScadaBiMapper scadaMapper;

    @Value("${commonSk}")
    private String commonSk;
    @Value("${carcertPath}")
    private String carcertPath;

    @Value("${sleepTime}")
    private Long sleepTime;

    @Override
    public void sendMqtt(List<JsonDataDto> dtoList) {
//        //解析sk文件
        //   String skFileValue = readSkFileToList(commonSk);
        MqttStartClient mq = new MqttStartClient();
        String skFileValue = mq.readSkFileToList(commonSk);
        JSONObject jsonObject = JSONObject.parseObject(skFileValue);
        Map<String, String> configParams = new HashMap<>();
        configParams.put(MqttEnum.MQTT_HOST.getMqttName(), jsonObject.getString("server"));
        String clientId = jsonObject.getString("version") + "." + jsonObject.getString("productType")
                + "." + jsonObject.getString("platform_id") + "." + jsonObject.getString("namespace")
                + "." + jsonObject.getString("productKey") + "." + jsonObject.getString("accessKey");
        configParams.put(MqttEnum.MQTT_CLIENTID.getMqttName(), clientId);
        configParams.put(MqttEnum.MQTT_USERNAME.getMqttName(), jsonObject.getString("accessKey"));
        configParams.put(MqttEnum.MQTT_PASSWORD.getMqttName(), jsonObject.getString("secretKey"));
        configParams.put(MqttEnum.MQTT_SSLROOT_CRTPATH.getMqttName(), carcertPath);
        configParams.put(MqttEnum.MQTT_SSLPROTOCOL.getMqttName(), MqttEnum.MQTT_TLS.getMqttName());
        String topic = "$SANY/gateway/pdev/sany/mdc/" + jsonObject.getString("accessKey") + "/data";
        configParams.put(MqttEnum.MQTT_TOPIC.getMqttName(), topic);

        final XBMqttDataUtil[] xbMqttDataUtil = {new XBMqttDataUtil(configParams)};

        // 线程循环发送Mqtt
        String threadName = "test-Thread";
        killThreadByName(threadName);
        new Thread(new Runnable() {
            @Override
            public void run() {
                while (true) {
                    try {
                        Long start = System.currentTimeMillis();
                        dtoList.forEach(t -> {
                            mqttStartClient.jqr(t, xbMqttDataUtil[0]);
                        });
                        Long end = System.currentTimeMillis();
                        log.info("-----------耗时：------------" + (end - start) / 1000);
                        Thread.sleep(sleepTime);
                    } catch (InterruptedException e) {
                        xbMqttDataUtil[0] = new XBMqttDataUtil(configParams);
                        continue;
                    }
                }
            }
        }, threadName).start();
    }

    //根据线程名称中断线程
    public boolean killThreadByName(String name) {
        // 获取所有线程
        ThreadGroup currentGroup = Thread.currentThread().getThreadGroup();
        int noThreads = currentGroup.activeCount();
        Thread[] lstThreads = new Thread[noThreads];
        currentGroup.enumerate(lstThreads);
        //System.out.println("现有线程个数：" + noThreads);

        for (int i = 0; i < noThreads; i++) {
            String threadName = lstThreads[i].getName();
            //System.out.println("第" + i + "个线程名为：" + threadName);
            // 中断指定的线程
            if (threadName.equals(name)) {
                System.out.println("中断线程：" + name);
                lstThreads[i].interrupt();
                return true;
            }
        }
        return false;
    }

    public Map<String, String> jgqgj(String name) {
        List<BldzCclmVo> jgqgjVos = scadaMapper.find(name);
        Map<String, String> jgqgjMap = new HashMap<>();
        for (BldzCclmVo bldzCclmVo : jgqgjVos) {
            if (bldzCclmVo != null) {

                jgqgjMap.put(bldzCclmVo.getBldz(), bldzCclmVo.getCclm().toLowerCase(Locale.ROOT));
            }
        }
        return jgqgjMap;
    }

    public Map<String, String> blx(String name) {
        List<BldzCclmVo> blxVos = scadaMapper.find(name);
        Map<String, String> blxMap = new HashMap<>();
        for (BldzCclmVo blxVo : blxVos) {
            if (blxVo != null) {
                if ("设备状态".equals(blxVo.getBlmc())) {
                    blxMap.put("Status", blxVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("是否报警".equals(blxVo.getBlmc())) {
                    blxMap.put("Alarm", blxVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                blxMap.put(blxVo.getBldz(), blxVo.getCclm().toLowerCase(Locale.ROOT));
            }
        }
        return blxMap;
    }

    public Map<String, String> xgjx(String name) {
        List<BldzCclmVo> xgjxcVos = scadaMapper.find(name);
        Map<String, String> xgjxcMap = new HashMap<>();
        for (BldzCclmVo xgjxcVo : xgjxcVos) {
            if (xgjxcVo != null) {
                if ("行车运行状态".equals(xgjxcVo.getBlmc())) {
                    xgjxcMap.put("Status", xgjxcVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("设备故障".equals(xgjxcVo.getBlmc())) {
                    xgjxcMap.put("Alarm", xgjxcVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("钢板重量".equals(xgjxcVo.getBlmc())) {
                    xgjxcMap.put("LiftWeight", xgjxcVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("行车z轴当前位置".equals(xgjxcVo.getBlmc())) {
                    xgjxcMap.put("LiftHeight", xgjxcVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("勾吊速度".equals(xgjxcVo.getBlmc())) {
                    xgjxcMap.put("LiftSpeed", xgjxcVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                //  xgjxcMap.put(xgjxcVo.getBldz(), xgjxcVo.getCclm().toLowerCase(Locale.ROOT));
            }
        }
        return xgjxcMap;
    }

    public Map<String, List<String>> mse(String name) {
        List<BldzCclmVo> msr52Vos = scadaMapper.find(name);
        Map<String, List<String>> msr52Map = new HashMap<>();
        for (BldzCclmVo msr52Vo : msr52Vos) {
            if (msr52Vo != null) {
                if ("切割状态开启".equals(msr52Vo.getBlmc()) || "切割状态关闭".equals(msr52Vo.getBlmc())) {
                    List<String> list = msr52Map.computeIfAbsent("Status", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("报警".contains(msr52Vo.getBlmc())) {
                    List<String> list = msr52Map.computeIfAbsent("Alarm", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("工作模式".equals(msr52Vo.getBlmc())) {
                    List<String> list = msr52Map.computeIfAbsent("Mode", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("绝对坐标X".equals(msr52Vo.getBlmc()) || "绝对坐标Y".equals(msr52Vo.getBlmc())) {
                    List<String> list = msr52Map.computeIfAbsent("AbsPos", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("NC程序启动".equals(msr52Vo.getBlmc()) || "NC程序停止".equals(msr52Vo.getBlmc())) {
                    List<String> list = msr52Map.computeIfAbsent("NcStatus", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("主程序号".equals(msr52Vo.getBlmc())) {
                    List<String> list = msr52Map.computeIfAbsent("MainPgm", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("当前程序号".equals(msr52Vo.getBlmc())) {
                    List<String> list = msr52Map.computeIfAbsent("CurPgm", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("加工时间".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("CycSec", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("程序行号".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("CurSeq", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("产量".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("PartCnt", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("当前程序块".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("CurNcBlk", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("切割速度".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("CutSpeed", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("板材规格".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("PlateType", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("切割气体流量".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("CutGasFlow", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                } else if ("保护气体流量".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("ProGasFlow", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                }
                if ("切割状态开启".equals(msr52Vo.getBlmc()) || "切割状态关闭".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("CutStatus", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                }
                if ("切割厚度".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("CutThick", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                }
                if ("引弧时间".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("ArcStrikeTime", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                }
                if ("弧压".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("ArcVoltage", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                }
                if ("工作电压".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("Voltage", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                }
                if ("隔缝补偿".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("GapOffset", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                }
                if ("工作电流".equals(msr52Vo.getBlmc())) {
                    //转化为秒
                    List<String> list = msr52Map.computeIfAbsent("Current", k -> new ArrayList<String>());
                    list.add(msr52Vo.getCclm());
                    continue;
                }


            }
        }
        return msr52Map;
    }

    public Map<String, String> xpj(String name) {
        List<BldzCclmVo> xpjVos = scadaMapper.find(name);
        Map<String, String> xpjMap = new HashMap<>();
        for (BldzCclmVo xpjVo : xpjVos) {
            if (xpjVo != null) {
                if ("设备状态".equals(xpjVo.getBlmc())) {
                    xpjMap.put("Status", xpjVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("报警".equals(xpjVo.getBlmc())) {
                    xpjMap.put("Alarm", xpjVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("最大板厚".equals(xpjVo.getBlmc())) {
                    xpjMap.put("MaxThickness", xpjVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("最大板宽".equals(xpjVo.getBlmc())) {
                    xpjMap.put("MaxWidth", xpjVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("校平速度".equals(xpjVo.getBlmc())) {
                    xpjMap.put("MaxSpeed", xpjVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("上辊行程".equals(xpjVo.getBlmc())) {
                    xpjMap.put("RealLength", xpjVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                if ("上辊角度".equals(xpjVo.getBlmc())) {
                    xpjMap.put("RealAngle", xpjVo.getCclm().toLowerCase(Locale.ROOT));
                    continue;
                }
                xpjMap.put(xpjVo.getBldz(), xpjVo.getCclm().toLowerCase(Locale.ROOT));
            }
        }
        return xpjMap;
    }

    public Map<String, List<String>> lmx(String name) {
        List<BldzCclmVo> blxVos = scadaMapper.find(name);
        Map<String, List<String>> lmxMap = new HashMap<>();
        for (BldzCclmVo blxVo : blxVos) {
            if (blxVo != null) {
                if ("序列号".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("SerNum", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("软件版本".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("nckVer", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("伺服轴数".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("Axes", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴数".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("SpinNum", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴最高转速".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("MaxSpeed", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }

                if ("状态运行".equals(blxVo.getBlmc()) || "状态故障报警".equals(blxVo.getBlmc()) || "状态机床等待".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("Status", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("状态急停".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("Emg", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("工作模式".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("Mode", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("轴名称1".equals(blxVo.getBlmc()) || "轴名称2".equals(blxVo.getBlmc()) || "轴名称3".equals(blxVo.getBlmc()) || "轴名称4".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("AxisName", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("机械坐标X".equals(blxVo.getBlmc()) || "机械坐标Y".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("MachPos", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("绝对坐标X".equals(blxVo.getBlmc()) || "绝对坐标Y".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("AbsPos", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("相对坐标X".equals(blxVo.getBlmc()) || "相对坐标Y".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("RelPos", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("剩余距离".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("RemPos", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }

                if ("程序运行状态".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("NcStatus", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主程序号".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("MainPgm", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("当前程序号".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("CurPgm", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("切削时间".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("CutTime", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("加工时间".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("CycSec", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("程序行号".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("CurSeq", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("产量".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("PartCnt", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("当前程序块".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("CurNcBlk", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("刀具号".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("TCode", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("切削倍率".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("OvFeed", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴倍率".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("OvSpin", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("切削速度".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("ActFeed", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("报警数量".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("alarmNums", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("报警类型".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("AlarmType", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("报警号".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("AlarmNo", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴速度".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("ActSpin", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴负载1".equals(blxVo.getBlmc())) {
                    List<String> list = lmxMap.computeIfAbsent("SpinLoad1", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
            }
        }
        return lmxMap;
    }

    public Map<String, List<String>> pmz(String name) {
        List<BldzCclmVo> blxVos = scadaMapper.find(name);
        Map<String, List<String>> pmzMap = new HashMap<>();
        for (BldzCclmVo blxVo : blxVos) {
            if (blxVo != null) {
                if ("序列号".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("SerNum", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("软件版本".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("nckVer", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("伺服轴数".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("Axes", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴数".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("SpinNum", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴最高转速".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("MaxSpeed", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("状态作业".equals(blxVo.getBlmc()) || "状态待机".equals(blxVo.getBlmc()) || "状态故障".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("Status", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("急停".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("Emg", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("报警".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("Alarm", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("工作模式".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("Mode", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("轴名称".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("AxisName", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("机械坐标".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("MachPos", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("绝对坐标".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("AbsPos", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("相对坐标".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("RelPos", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("剩余距离".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("RemPos", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }

                if ("程序运行状态".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("NcStatus", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主程序号".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("MainPgm", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主程序注释".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("MainPgmMsg", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("当前程序号".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("CurPgm", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("当前程序注释".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("CurPgmMsg", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("切削时间".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("CutTime", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("加工时间".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("CycSec", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("程序行号".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("CurSeq", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("产量".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("PartCnt", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("当前程序块".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("CurNcBlk", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("刀具号".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("TCode", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("切削倍率".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("OvFeed", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴倍率".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("OvSpin", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("切削速度".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("ActFeed", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("切削指定速度".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("FCode", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴速度".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("ActSpin", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
                if ("主轴负载1".equals(blxVo.getBlmc())) {
                    List<String> list = pmzMap.computeIfAbsent("SpinLoad1", k -> new ArrayList<String>());
                    list.add(blxVo.getCclm());
                    continue;
                }
            }
        }
        return pmzMap;
    }

    /**
     * 获取证书sk解析后的码
     *
     * @return
     */
    public static String readSkFileToList(String skFile) {
        ///File file = new File(skFile);
        List<String> filelist = new ArrayList();
        filelist = returnFileCs(skFile);

        String info = "";
        // 遍历listStr集合
        for (String data : filelist) {
            // +换行
            info = info + data;
        }
        Base64.Decoder decoder = Base64.getDecoder();
        byte[] bytes = decoder.decode(info);
        return new String(bytes);
    }

    public static List<String> returnFileCs(String path) {
        List<String> listStr = new ArrayList<>();
        String url = System.getProperty("user.dir");
        // System.out.println(url);
        BufferedReader br;
        try {
            br = new BufferedReader(new InputStreamReader(new FileInputStream(url + path), "UTF-8"));
            String tempStr;
            while ((tempStr = br.readLine()) != null) {
                listStr.add(tempStr);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return listStr;
    }


}
